@@ -901,7 +901,7 @@ void CMACDlg::OnToolsOptions()
     }
 }
 
-int CMACDlg::GetScaledFontHeight(int nStart)
+int CMACDlg::GetScaledFontHeight(int nStart) const
 {
     // get size
     //nStart = theApp.GetSize(nStart); // no need to do this because the font is already sized for the scale
