@@ -1,7 +1,7 @@
 #include "All.h"
 #include "APELink.h"
 #include "CharacterHelper.h"
-#include "IO.h"
+#include "IAPEIO.h"
 namespace APE
 {
 
@@ -19,15 +19,15 @@ CAPELink::CAPELink(const str_utfn * pFilename)
     m_cImageFilename[0] = 0;
 
     // open the file
-    CSmartPtr<CIO> spioLinkFile(CreateCIO());
+    CSmartPtr<IAPEIO> spioLinkFile(CreateIAPEIO());
     if (spioLinkFile->Open(pFilename) == ERROR_SUCCESS)
     {
         // create a buffer
-        CSmartPtr<char> spBuffer(new char [1024], true);
+        CSmartPtr<char> spBuffer(new char [4097], true);
 
-        // fill the buffer from the file and null terminate it
+        // fill the buffer from the file and null terminate it (this might read less if the file is shorter, but that's fine)
         unsigned int nBytesRead = 0;
-        spioLinkFile->Read(spBuffer.GetPtr(), 1023, &nBytesRead);
+        spioLinkFile->Read(spBuffer.GetPtr(), 4096, &nBytesRead);
         spBuffer[nBytesRead] = 0;
 
         // call the other constructor (uses a buffer instead of opening the file)
@@ -78,7 +78,7 @@ void CAPELink::ParseData(const char * pData, const str_utfn * pFilename)
                     cImageFile[nIndex++] = *pImageCharacter++;
                 cImageFile[nIndex] = 0;
 
-                CSmartPtr<str_utfn> spImageFileUTF16(CAPECharacterHelper::GetUTF16FromUTF8(reinterpret_cast<const str_utf8 *>(cImageFile)), true);
+                CSmartPtr<str_utfn> spImageFileUTF16(CAPECharacterHelper::GetUTFNFromUTF8(reinterpret_cast<const str_utf8 *>(cImageFile)), true);
 
                 // process the path
                 if ((wcsrchr(spImageFileUTF16, APE_FILENAME_SLASH) == APE_NULL) && (wcsrchr(pFilename, APE_FILENAME_SLASH) != APE_NULL))
@@ -101,12 +101,12 @@ void CAPELink::ParseData(const char * pData, const str_utfn * pFilename)
     }
 }
 
-int CAPELink::GetStartBlock()
+int CAPELink::GetStartBlock() const
 {
     return m_nStartBlock;
 }
 
-int CAPELink::GetFinishBlock()
+int CAPELink::GetFinishBlock() const
 {
     return m_nFinishBlock;
 }
@@ -116,7 +116,7 @@ const str_utfn * CAPELink::GetImageFilename()
     return m_cImageFilename;
 }
 
-bool CAPELink::GetIsLinkFile()
+bool CAPELink::GetIsLinkFile() const
 {
     return m_bIsLinkFile;
 }
